@@ -17,9 +17,16 @@
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 
+import openstackdocstheme
+
+html_theme = 'openstackdocs'
+html_theme_path = [openstackdocstheme.get_html_theme_path()]
+html_theme_options = {
+    "sidebar_mode": "toc",
+}
+
 extensions = [
     'os_api_ref',
-    'oslosphinx',
 ]
 
 # The suffix of source filenames.
